| Title: | PEcAn Package for Integration of the JULES Model |
|---|---|
| Description: | This module provides functions to link the (JULES) to PEcAn. |
| Authors: | Mike Dietze [aut, cre], University of Illinois, NCSA [cph] |
| Maintainer: | Mike Dietze <[email protected]> |
| License: | BSD_3_clause + file LICENSE |
| Version: | 1.7.5.9000 |
| Built: | 2026-06-05 14:47:37 UTC |
| Source: | https://github.com/PecanProject/pecan |
Detect timestep of JULES met files
detect.timestep(met.dir, met.regexp, start_date)detect.timestep(met.dir, met.regexp, start_date)
met.dir |
path to directory containing met files |
met.regexp |
pattern to match to find a met file in met.dir. If more than one file matches, only the first will be used. |
start_date |
When in file to start checking deltas. Not used if timestep can be detected from the CDF header. |
a difftime object
Convert MODEL output into the PEcAn standard
model2netcdf.JULES(outdir)model2netcdf.JULES(outdir)
outdir |
Location of model output |
Michael Dietze
Requires a pft xml object, a list of trait values for a single model run, and the name of the file to create
write.config.JULES(defaults, trait.values, settings, run.id)write.config.JULES(defaults, trait.values, settings, run.id)
defaults |
list of defaults to process |
trait.values |
vector of samples for a given trait |
settings |
list of settings from pecan settings file |
run.id |
id of run |
configuration file for JULES for given run
Mike Dietze, Rob Kooper
## Not run: settings <- PEcAn.settings::read.settings("pecan.xml") write.config.JULES(defaults, trait.values, settings, run.id) ## End(Not run)## Not run: settings <- PEcAn.settings::read.settings("pecan.xml") write.config.JULES(defaults, trait.values, settings, run.id) ## End(Not run)